==> ipmi-0.9.tar.gz: ipmi-0.9/ipmi/format_func.py <==
#!/usr/bin/env python
# coding: utf-8

from const import HDRMAP


def ipmi_sensor_netxms_format(
        doc, record_delimiter, show_header=False,
        filter_thresholds=False, sensor_name=None, list_sensor_types=False):
    """
    translate the header and extract the doc into dict
    ordering: reading, lower nc, upper nc, lower c, upper c
    """
    doc_by_row = doc.split("\n")
    header = doc_by_row[0]
    body = doc_by_row[1:]

    origin_header_list = map(lambda i: i.strip(), header.split("|"))
    header_list = [HDRMAP.get(h) for h in origin_header_list]

    result_dict = []
    for row in body:
        if not row:
            continue

        row_fields = map(lambda i: i.strip(), row.split("|"))
        row_ret = {
            header_list[i]: row_fields[i]
            for i in range(len(header_list))
        }
        # if row_ret["reading"] != "N/A":
        result_dict.append(row_ret)

    body = []
    for row in result_dict:
        if sensor_name:
            # filter sensor name
            if sensor_name != row["name"]:
                continue
        if filter_thresholds:
            body_line = ";".join([
                row["id"], row["name"], row["type"], row["state"],
                row["event"], row["reading"], row["units"],
            ])
        elif list_sensor_types:
            body_line = ";".join([row["type"], row["name"]])
        else:
            body_line = ";".join([
                row["id"], row["name"], row["type"], row["state"],
                row["event"], row["reading"], row["units"],
                row["lowerC"], row["lowerNC"], row["upperNC"], row["upperC"],
            ])
        body.append(body_line)

    if show_header:
        if filter_thresholds:
            header = ";".join([
                "ID", "Name", "Type", "Status", "Event", "Reading", "Unit",
            ])
        elif list_sensor_types:
            header = ";".join([
                "Type", "Name",
            ])
        else:
            header = ";".join([
                "ID", "Name", "Type", "Status", "Event", "Reading", "Unit",
                "LowCT", "Low NC", "High NC", "High CT",
            ])
        body.insert(0, header)

    return record_delimiter.join(body)

==> ipmi-1.1.tar.gz: ipmi-1.1/ipmi/format_func.py <==
#!/usr/bin/env python
# coding: utf-8

from const import HDRMAP


def ipmi_sensor_netxms_format(
        doc, record_delimiter, show_header=False,
        filter_thresholds=False, sensor_name=None,
        list_sensor_types=False, filter_by_headers=None):
    """
    translate the header and extract the doc into dict
    ordering: reading, lower nc, upper nc, lower c, upper c
    """
    doc_by_row = doc.split("\n")
    header = doc_by_row[0]
    body = doc_by_row[1:]

    origin_header_list = map(lambda i: i.strip(), header.split("|"))
    header_list = [HDRMAP.get(h) for h in origin_header_list]

    if filter_by_headers:
        header_filter_list = filter(
            lambda header: header, filter_by_headers.split(","))
        header_key_list = []
        for header in header_filter_list:
            if header not in HDRMAP:
                raise Exception, "{} is a wrong header!".format(header)
            else:
                header_key_list.append(HDRMAP.get(header))

    result_dict = []
    for row in body:
        if not row:
            continue

        row_fields = map(lambda i: i.strip(), row.split("|"))
        row_ret = {
            header_list[i]: row_fields[i]
            for i in range(len(header_list))
        }
        result_dict.append(row_ret)

    body = []
    for row in result_dict:
        if sensor_name:
            # filter sensor name
            if sensor_name != row["name"]:
                continue
        if filter_thresholds:
            body_line = ";".join([
                row["id"], row["name"], row["type"], row["state"],
                row["event"], row["reading"], row["units"],
            ])
        elif list_sensor_types:
            body_line = ";".join([row["type"], row["name"]])
        elif filter_by_headers:
            body_line = ";".join([
                row[header] for header in header_key_list
            ])
        else:
            body_line = ";".join([
                row["id"], row["name"], row["type"], row["state"],
                row["event"], row["reading"], row["units"],
                row["lowerC"], row["lowerNC"], row["upperNC"], row["upperC"],
            ])
        body.append(body_line)

    if show_header:
        if filter_thresholds:
            header = ";".join([
                "ID", "Name", "Type", "Status", "Event", "Reading", "Unit",
            ])
        elif list_sensor_types:
            header = ";".join([
                "Type", "Name",
            ])
        elif filter_by_headers:
            header = filter_by_headers.replace(",", ";")
        else:
            header = ";".join([
                "ID", "Name", "Type", "Status", "Event", "Reading", "Unit",
                "LowCT", "Low NC", "High NC", "High CT",
            ])
        body.insert(0, header)

    return record_delimiter.join(body)
